ObjectPath

Struct ObjectPath 

pub struct ObjectPath(/* private fields */);
A validated object path.

The following rules define a valid object path. Implementations must not send or accept messages with invalid object paths.

  • The path may be of any length.
  • The path must begin with an ASCII ‘/’ (integer 47) character, and must consist of elements separated by slash characters.
  • Each element must only contain the ASCII characters “[A-Z][a-z][0-9]_”
  • No element may be the empty string.
  • Multiple ‘/’ characters cannot occur in sequence.
  • A trailing ‘/’ character is not allowed unless the path is the root path (a single ‘/’ character).

Implementations

Source

impl ObjectPath

pub const ROOT: &'static Self

The special "/" object path.

Examples
use tokio_dbus::ObjectPath;

assert_eq!(ObjectPath::ROOT, ObjectPath::new(b"/")?);
pub const fn new_const(path: &[u8]) -> &Self

Construct a new object path.

Panics

Panics if the argument is not a valid object.

See ObjectPath for more information.

pub fn new<P>(path: &P) -> Result<&Self, ObjectPathError>
where P: ?Sized + AsRef<[u8]>,

Construct a new validated object path.

Errors

Errors if the argument is not a valid object.

See ObjectPath for more information.

pub fn iter(&self) -> Iter<'_>

Construct an iterator over the object path.

Examples
use tokio_dbus::ObjectPath;

let mut it = ObjectPath::new_const(b"/").iter();
assert!(it.next().is_none());

let mut it = ObjectPath::new_const(b"/foo").iter();
assert_eq!(it.next(), Some("foo"));
assert!(it.next().is_none());

let mut it = ObjectPath::new_const(b"/foo/bar").iter();
assert_eq!(it.next_back(), Some("bar"));
assert_eq!(it.next(), Some("foo"));
assert!(it.next().is_none());
pub fn starts_with(&self, other: &ObjectPath) -> bool

Test if one part starts with another.

Examples
use tokio_dbus::ObjectPath;

const FOO: &ObjectPath = ObjectPath::new_const(b"/foo");
const FOO_BAR: &ObjectPath = ObjectPath::new_const(b"/foo/bar");

assert!(FOO_BAR.starts_with(FOO));