RawArray

Struct RawArray 

pub struct RawArray<'a> { /* private fields */ }
A writer for the elements of an array whose shape is only known at runtime.

See Raw::store_array.

Implementations

Source

impl<'a> RawArray<'a>

pub fn as_raw(&mut self) -> Raw<'_>

Write the next element of the array.

pub fn finish(self)

Finish writing the array.

This also happens implicitly when the writer is dropped.