Signature

Struct Signature 

pub struct Signature(/* private fields */);
A D-Bus signature.

Examples

use tokio_dbus::Signature;

const SIG: &Signature = Signature::new_const(b"aaaai");

assert!(Signature::new(b"aai").is_ok());

Implementations

Source

impl Signature

pub const EMPTY: &'static Signature

The empty signature.

Examples
use tokio_dbus::{BodyBuf, Signature};

let body = BodyBuf::new();
assert_eq!(body.signature(), Signature::EMPTY);
pub const SIGNATURE: &'static Signature

The signature of a Signature.

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();
body.store(Signature::new(b"g")?);

assert_eq!(body.signature(), Signature::SIGNATURE);
pub const OBJECT_PATH: &'static Signature

The signature of an object path.

Examples
use tokio_dbus::{BodyBuf, Signature, ObjectPath};

let mut body = BodyBuf::new();
body.store(ObjectPath::new(b"/org/freedesktop/DBus")?);

assert_eq!(body.signature(), Signature::OBJECT_PATH);
pub const STRING: &'static Signature

The signature of a nul-terminated string.

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();
body.store("Hello World!");

assert_eq!(body.signature(), Signature::STRING);
pub const VARIANT: &'static Signature

The signature of a variant value.

Examples
use tokio_dbus::{BodyBuf, Signature, Variant};

let mut body = BodyBuf::new();
body.store(Variant::U32(10u32));

assert_eq!(body.signature(), Signature::VARIANT);
pub const BOOLEAN: &'static Signature

A boolean value, marshalled as a 32-bit integer which is either 0 or 1.

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();

body.store(true);

assert_eq!(body.signature(), Signature::BOOLEAN);
pub const BYTE: &'static Signature

A single byte.

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();

body.store(10u8);

assert_eq!(body.signature(), Signature::BYTE);
pub const INT16: &'static Signature

Signed (two’s complement) 16-bit integer.

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();

body.store(10i16);

assert_eq!(body.signature(), Signature::INT16);
pub const UINT16: &'static Signature

Unsigned 16-bit integer.

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();

body.store(10u16);

assert_eq!(body.signature(), Signature::UINT16);
pub const INT32: &'static Signature

Signed (two’s complement) 32-bit integer

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();

body.store(10i32);

assert_eq!(body.signature(), Signature::INT32);
pub const UINT32: &'static Signature

Unsigned 32-bit integer

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();

body.store(10u32);

assert_eq!(body.signature(), Signature::UINT32);
pub const INT64: &'static Signature

Signed (two’s complement) 64-bit integer (mnemonic: x and t are the first characters in “sixty” not already used for something more common)

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();

body.store(10i64);

assert_eq!(body.signature(), Signature::INT64);
pub const UINT64: &'static Signature

Unsigned 64-bit integer

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();

body.store(10u64);

assert_eq!(body.signature(), Signature::UINT64);
pub const DOUBLE: &'static Signature

IEEE 754 double-precision floating point

Examples
use tokio_dbus::{BodyBuf, Signature};

let mut body = BodyBuf::new();

body.store(3.1415f64);

assert_eq!(body.signature(), Signature::DOUBLE);
pub const UNIX_FD: &'static Signature

Unsigned 32-bit integer representing an index into an out-of-band array of file descriptors, transferred via some platform-specific mechanism (mnemonic: h for handle)

pub const fn new_const(signature: &[u8]) -> &Signature

Construct a new signature with validation inside of a constant context.

This will panic in case the signature is invalid.

use tokio_dbus::Signature;

const BAD: &Signature = Signature::new_const(b"(a)");
Examples
use tokio_dbus::Signature;

const SIG: &Signature = Signature::new_const(b"i(ai)");
pub fn new<S>(signature: &S) -> Result<&Signature, SignatureError>
where S: AsRef<[u8]> + ?Sized,

Try to construct a new signature with validation.

pub const unsafe fn new_unchecked(signature: &[u8]) -> &Signature

Construct a new signature without validation. The caller is responsible for ensuring that the signature is valid.

Safety

The caller must ensure that the signature is a valid signature.

pub const fn empty() -> &'static Signature

Construct a new empty signature.

pub fn is_empty(&self) -> bool

Test if the signature is empty.

pub fn len(&self) -> usize

Get the length of the signature in bytes.

pub fn iter(&self) -> Iter<'_>

pub fn as_str(&self) -> &str

Get the signature as a string.

pub fn as_bytes(&self) -> &[u8]

Get the signature as a byte slice.