StoreStruct

Struct StoreStruct 

pub struct StoreStruct<'a, T> { /* private fields */ }
Write a struct.

See BodyBuf::store_struct.

Implementations

Source

impl<'a, T> StoreStruct<'a, T>

pub fn store( self, value: <T::First as Marker>::Return<'_>, ) -> StoreStruct<'a, T::Remaining>
where T: Fields, T::First: Marker, for<'b> <T::First as Marker>::Return<'b>: Storable,

Store a value and return the builder for the next value to store.

Examples
use tokio_dbus::{BodyBuf, Endianness};
use tokio_dbus::ty;

let mut buf = BodyBuf::with_endianness(Endianness::LITTLE);

buf.store_struct::<(u16, u32)>()?
    .store(10u16)
    .store(10u32)
    .finish();

assert_eq!(buf.signature(), b"(qu)");
assert_eq!(buf.get(), &[10, 0, 0, 0, 10, 0, 0, 0]);

Examples using unsized types:

use tokio_dbus::{BodyBuf, Endianness};
use tokio_dbus::ty;

let mut buf = BodyBuf::with_endianness(Endianness::LITTLE);

buf.store_struct::<(ty::Str,)>()?
    .store("Hello World")
    .finish();

assert_eq!(buf.signature(), b"(s)");
assert_eq!(buf.get(), &[11, 0, 0, 0, 72, 101, 108, 108, 111, 32, 87, 111, 114, 108, 100, 0]);
pub fn fields(self, arguments: T)
where T: Arguments,

Store a value and return the builder for the next value to store.

Examples
use tokio_dbus::{BodyBuf, Endianness};
use tokio_dbus::ty;

let mut buf = BodyBuf::with_endianness(Endianness::LITTLE);

buf.store_struct::<(u8, u32)>()?.fields((42u8, 42u32));

assert_eq!(buf.signature(), b"(yu)");
assert_eq!(buf.get(), &[42, 0, 0, 0, 42, 0, 0, 0]);
pub fn store_array<W, U>(self, writer: W) -> StoreStruct<'a, T::Remaining>
where W: FnOnce(&mut StoreArray<'_, U>), T: Fields<First = Array<U>>, U: Aligned,

Store a value and return the builder for the next value to store.

Examples
use tokio_dbus::{BodyBuf, Endianness};
use tokio_dbus::ty;

let mut buf = BodyBuf::with_endianness(Endianness::LITTLE);

buf.store_struct::<(ty::Array<u32>,)>()?
    .store_array(|w| {
        w.store(1);
        w.store(2);
        w.store(3);
        w.store(4);
    })
    .finish();

assert_eq!(buf.signature(), b"(au)");
assert_eq!(buf.get(), &[16, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0]);
pub fn store_struct<W>(self, writer: W) -> StoreStruct<'a, T::Remaining>
where W: FnOnce(StoreStruct<'_, T::First>), T: Fields, T::First: Fields,

Store a nested struct and return the builder for the next value to store.

Examples
use tokio_dbus::{BodyBuf, Endianness};
use tokio_dbus::ty;

let mut buf = BodyBuf::with_endianness(Endianness::LITTLE);

buf.store_struct::<((u32, ty::Str), u8)>()?
    .store_struct(|w| {
        w.store(42u32).store("Hello World").finish();
    })
    .store(1u8)
    .finish();

assert_eq!(buf.signature(), b"((us)y)");

let mut buf = buf.as_body();
let ((n, string), b) = buf.load_struct::<((u32, ty::Str), u8)>()?;

assert_eq!(n, 42);
assert_eq!(string, "Hello World");
assert_eq!(b, 1);
pub fn store_variant<W>( self, signature: &Signature, writer: W, ) -> StoreStruct<'a, T::Remaining>
where W: FnOnce(StoreVariant<'_>), T: Fields<First = Variant>,

Store a variant and return the builder for the next value to store.

Examples
use tokio_dbus::{ty, BodyBuf, Signature, Variant};

let mut buf = BodyBuf::new();

buf.store_struct::<(u32, ty::Variant)>()?
    .store(42u32)
    .store_variant(Signature::STRING, |w| w.store("Hello World!"))
    .finish();

assert_eq!(buf.signature(), "(uv)");

let mut buf = buf.as_body();
let (n, value) = buf.load_struct::<(u32, ty::Variant)>()?;

assert_eq!(n, 42);
assert_eq!(value, Variant::String("Hello World!"));
Source

impl StoreStruct<'_, ()>

pub fn finish(self)

Finish writing the struct.

See BodyBuf::store_struct.